﻿using IDTechSDK;



if (IDT_Device.isUnix()) Console.WriteLine("Running On Unix (Linux/Mac)");
else Console.WriteLine("Running On Windows");

//Set interface type: DEVICE_INTERFACE_Types.DEVICE_INTERFACE_SERIAL or DEVICE_INTERFACE_Types.DEVICE_INTERFACE_USB
DEVICE_INTERFACE_Types interfaceType = DEVICE_INTERFACE_Types.DEVICE_INTERFACE_USB;

//Set Device Type:
IDT_DEVICE_Types type = IDT_DEVICE_Types.IDT_DEVICE_NEO2;


//Serial Drivers


if (interfaceType == DEVICE_INTERFACE_Types.DEVICE_INTERFACE_SERIAL)
{
    //The following will attempt to mount the first serial device found (COMxx on windows, 
    //ttyusbxx on Linux, cu.usbserial on Mac)  using device default serial port settings
    //Alternately, you can use the same method to also specify specific port, baud, and/or Linux/Mac device path
    if (!IDT_Device.useSerialPort(type))
    {
        Console.WriteLine("No Serial Device Found!");
        Console.ReadKey();
        return;
    }
}
else   //conect via USB
{
    // Enable USB Monitoring
    // For purposes of this demo, the expectation is the device is already on USB bus at start of program
    IDT_Device.startUSBMonitoring();

    //Tell the SDK to use the specific device on the USB bus.  USB is the default connection
    //Alternately, setDeviceType can specify connection,protocol, and IP address.
    IDT_Device.setDeviceType(type);

}

//Let's wait for a device to show up on USB Bus
//Normally, you would implement the MessageCallback and be notified when devices connect/disconnect, but in this case
//we are not implementing any callback and will just poll for device.

List<string> connectedDevices = Profile.getAllConnections(interfaceType);
int tries = 0;
while(connectedDevices.Count == 0 && tries < 5)
{
    Console.WriteLine("No Device Found. Make sure a device is plugged in and given enough time to be recognized.");
    Console.WriteLine("Press a key to continue!");
    Console.ReadKey();
    Profile.getAllConnections(interfaceType);
    tries++;
}

string ident = "";
if (connectedDevices.Count > 0) ident = connectedDevices[0];
//Lets check if a device successfully connected by seeing if it's communication class was created
IDTechComm comm = Profile.getComm(ident);
if (comm == null)
{
    Console.WriteLine("No Communication Established. Press a key to continue!");
    Console.ReadKey();
    return;
}

Console.WriteLine("Device Found! Press a key to continue!");
Console.ReadKey();
string firmwareVersion = "";
RETURN_CODE rt = IDT_Device.SharedController.device_getFirmwareVersion(ref firmwareVersion, ident);
if (rt == RETURN_CODE.RETURN_CODE_DO_SUCCESS)
{
    Console.WriteLine("Firmware Ver: " + firmwareVersion + "\r\n");
}
else
{
    Console.WriteLine("Get Firmware Fail Error Code: " + "0x" + String.Format("{0:X}", (ushort)rt) +
                        ": " + IDTechSDK.errorCode.getErrorString(rt) + "\r\n");
}

if (interfaceType == DEVICE_INTERFACE_Types.DEVICE_INTERFACE_USB) IDT_Device.stopUSBMonitoring();
Console.WriteLine("Press a key to exit!");
Console.ReadKey();
